0-正在查询中
1-揽收中
2-在途中
 204  货件到达枢纽或分拣中心
 211  包裹到达附近代取点
 222	到达目的国/地区
 220	从机场出发
 221	到达目的机场
派送
 202	包裹派送中
 223	派送前联系客户
 224	预约派送
3-签收
 301	成功签收
 305	客户签名签收
 306	客户自提成功
 307	货到付款成功
 304	第三方代签收
4-问题件
 420	收货地址不可用
 416	找不到收件人
 415	交货时，业务取消
 404	收件人拒收，交付失败
 424	客户长期不领取包裹
 425	包裹正在退回给发件人中
 406	包裹已成功退回发件人
 414	包裹破损、遗失或被丢弃
 426	包裹丢失
 427	包裹违规，承运商拒绝
 420	收件人地址不正确
 430	订单在揽件前被取消
6-清关
 605	移交清关
 603	清关完成
 604	清关问题，包裹延误
 606	客户未付款，海关扣留
